@@ -4,9 +4,13 @@ from typing import Any, Callable, Generic, Optional, TypeVar
 
 import grpc
 
-from rime_sdk.protos.model_testing_pb2_grpc import ModelTestingStub
-from rime_sdk.protos.results_upload_pb2_grpc import ResultsStoreStub
-from rime_sdk.protos.test_run_tracker_pb2_grpc import TestRunTrackerStub
+from rime_sdk.protos.image_registry.image_registry_pb2_grpc import ImageRegistryStub
+from rime_sdk.protos.model_testing.model_testing_pb2_grpc import ModelTestingStub
+from rime_sdk.protos.results_upload.results_upload_pb2_grpc import ResultsStoreStub
+from rime_sdk.protos.test_run_results.test_run_results_pb2_grpc import ResultsReaderStub
+from rime_sdk.protos.test_run_tracker.test_run_tracker_pb2_grpc import (
+    TestRunTrackerStub,
+)
 
 # Generic type representing a client stub for a gRPC server.
 C = TypeVar("C")
@@ -130,9 +134,20 @@ class RIMEBackend:
         if domain_split[0][-4:] != "rime":
             raise ValueError("The configuration must be a valid rime webapp url")
         base_domain = domain_split[1]
+        self._image_registry_addr = self._get_image_registry_addr(base_domain)
         self._model_testing_addr = self._get_model_testing_addr(base_domain)
         self._results_store_addr = self._get_results_store_addr(base_domain)
         self._test_run_tracker_addr = self._get_test_run_tracker_addr(base_domain)
+        self._test_run_results_addr = self._get_test_run_results_addr(base_domain)
+
+    def _get_image_registry_addr(self, domain: str) -> str:
+        """Construct an address to the image-registry service from `domain`.
+
+        Args:
+            domain: str
+                The base domain/address of the RIME service.
+        """
+        return f"rime-image-registry.{domain}:443"
 
     def _get_model_testing_addr(self, domain: str) -> str:
         """Construct an address to the model-testing service from `domain`.
@@ -161,6 +176,24 @@ class RIMEBackend:
         """
         return f"rime-test-run-tracker.{domain}:443"
 
+    def _get_test_run_results_addr(self, domain: str) -> str:
+        """Construct an address to the test-run-results service from `domain`.
+
+        Args:
+            domain: str
+                The base domain/address of the RIME service.
+        """
+        return f"rime-test-run-results.{domain}:443"
+
+    def get_image_registry_stub(self) -> RIMEConnection[ImageRegistryStub]:
+        """Return an image registry client."""
+        return RIMEConnection[ImageRegistryStub](
+            ImageRegistryStub,
+            self._image_registry_addr,
+            self._api_key,
+            channel_timeout=self._channel_timeout,
+        )
+
     def get_model_testing_stub(self) -> RIMEConnection[ModelTestingStub]:
         """Return a model testing client."""
         return RIMEConnection[ModelTestingStub](
@@ -187,3 +220,12 @@ class RIMEBackend:
             self._api_key,
             channel_timeout=self._channel_timeout,
         )
+
+    def get_test_run_results_stub(self) -> RIMEConnection[ResultsReaderStub]:
+        """Return a test run results reader client."""
+        return RIMEConnection[ResultsReaderStub](
+            ResultsReaderStub,
+            self._test_run_results_addr,
+            self._api_key,
+            channel_timeout=self._channel_timeout,
+        )
